import QtQuick 2.3
import Fly.Components 1.0

FlyNotificationItem {
    id: notificationItem

    property bool mounted: _notification && _notification.dataMap["mounted"]
    property bool error: _notification && _notification.dataMap["error"]

    description.visible: false
    description.y: height * 0.6
    description.height: height * 0.4

    icon.imagePath: "image://ThemeImageProvider/drive-removable-media-usb"
    icon.imageColorEnabled: true
    icon.imageColor: styles.highlightColor

    function clicked() {
        return true; // close notification panel
    }

    property bool errorShown: false

    function showError() {
        if (error && !errorShown) {
            root.showMessagePage({
                                  "title": _notification.dataMap["error_title"],
                                  "message": _notification.dataMap["error_message"],
                                  "titleImage.imagePath": icon.imagePath,
                                  "showCancelButton": false,
                                  "okFunction": function() {
                                      errorShown = false
                                      ejectButton.enabled = true
                                  }
                                 })
            errorShown = true
            ejectButton.enabled = false
        }
    }

    onErrorChanged: showError()

    FlySeparator { x: description.x; y: description.y - height + 1; width: description.width }

    Row {
        id: btnRow
        anchors.fill: description

        readonly property bool isRus: Qt.locale().name.substring(0,2) === "ru"

        // NOTE: currently there is no localization of custom notifications in fly-launcher
        function trString(str) {
            if(!isRus) return str;
            switch (str) {
            case "Open": return "Открыть";
            case "Eject": return "Извлечь";
            case "Can be ejected": return "Можно извлекать";
            }
            return str;
        }

        FlyMenuButton {
            width: parent.width / 2 - sep.width / 2
            text: btnRow.trString("Open")
            image.imagePath: "image://ThemeImageProvider/system-file-manager"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("open")
        }

        FlySeparator { id: sep; horizontal: false }

        FlyMenuButton {
            id: ejectButton
            enabled: mounted
            width: parent.width / 2 - sep.width / 2
            text: mounted ? btnRow.trString("Eject") : btnRow.trString("Can be ejected")
            image.imagePath: "image://ThemeImageProvider/media-eject"
            image.imageColorEnabled: true
            image.imageColor: styles.highlightColor
            buttonRow.anchors.horizontalCenter: buttonRow.parent.horizontalCenter
            onClicked: if(_notification) _notification.newData("eject")
        }
    }
}
